==> haskell-protolude-0.3.4-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 protolude
version:              0.3.4
visibility:           public
id:                   protolude-0.3.4-C68lxRwT6wM7hTLtjmS1SJ
key:                  protolude-0.3.4-C68lxRwT6wM7hTLtjmS1SJ
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  a09db655d40bfd35406a60251a6992c0
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.2.8/site-local/protolude-0.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/protolude-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.4-C68lxRwT6wM7hTLtjmS1SJ
depends:
    array-0.5.4.0 async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    ghc-prim-0.8.0 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL mtl-2.2.2
    stm-2.5.0.2 text-1.2.5.0 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-protolude-0.3.4-7.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-protolude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 protolude
version:              0.3.4
visibility:           public
id:                   protolude-0.3.4-erquiU8swABHjzXTMSoGn
key:                  protolude-0.3.4-erquiU8swABHjzXTMSoGn
license:              MIT
copyright:            2016-2022 Stephen Diehl
maintainer:           adamwespiser@gmail.com, stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  fad9a49270cc6fc7f0b22bc324a77970
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-9.2.8/site-local/protolude-0.3.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/protolude-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-protolude
hs-libraries:         HSprotolude-0.3.4-erquiU8swABHjzXTMSoGn
depends:
    array-0.5.4.0 async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    ghc-prim-0.8.0 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r mtl-2.2.2
    stm-2.5.0.2 text-1.2.5.0 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
